featurevectormatrix package
===========================

Submodules
----------

featurevectormatrix.featurevectormatrix module
----------------------------------------------

.. automodule:: featurevectormatrix.featurevectormatrix
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: featurevectormatrix
    :members:
    :undoc-members:
    :show-inheritance:
